==> tool-sql-2.6.0-pre-sources.jar: io/ciera/tool/sql/architecture/statement/StatementSet.java <==
package io.ciera.tool.sql.architecture.statement;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.invocable.CodeBlockSet;
import io.ciera.tool.sql.architecture.statement.BreakSmtSet;
import io.ciera.tool.sql.architecture.statement.ContinueSmtSet;
import io.ciera.tool.sql.architecture.statement.DeleteSmtSet;
import io.ciera.tool.sql.architecture.statement.ExpressionAsStatementSet;
import io.ciera.tool.sql.architecture.statement.FinalizationSet;
import io.ciera.tool.sql.architecture.statement.ForSmtSet;
import io.ciera.tool.sql.architecture.statement.GenerateSet;
import io.ciera.tool.sql.architecture.statement.HaltSet;
import io.ciera.tool.sql.architecture.statement.IfSmtSet;
import io.ciera.tool.sql.architecture.statement.NullSmtSet;
import io.ciera.tool.sql.architecture.statement.RelateSmtSet;
import io.ciera.tool.sql.architecture.statement.ReturnSmtSet;
import io.ciera.tool.sql.architecture.statement.StatementSet;
import io.ciera.tool.sql.architecture.statement.UnrelateSmtSet;
import io.ciera.tool.sql.architecture.statement.VariableSet;
import io.ciera.tool.sql.architecture.statement.WhileSmtSet;


public interface StatementSet extends IInstanceSet<StatementSet,Statement> {

    // attributes
    public void setParent_name( String ref_parent_name ) throws XtumlException;
    public void setBody_name( String ref_body_name ) throws XtumlException;
    public void setPrefix( String m_prefix ) throws XtumlException;
    public void setParent_package( String ref_parent_package ) throws XtumlException;
    public void setNext_statement_number( String ref_next_statement_number ) throws XtumlException;
    public void setStatement_number( String m_statement_number ) throws XtumlException;
    public void setOal( String m_oal ) throws XtumlException;
    public void setBlock_number( String ref_block_number ) throws XtumlException;


    // selections
    public CodeBlockSet R450_is_contained_by_CodeBlock() throws XtumlException;
    public BreakSmtSet R451_is_a_BreakSmt() throws XtumlException;
    public ContinueSmtSet R451_is_a_ContinueSmt() throws XtumlException;
    public DeleteSmtSet R451_is_a_DeleteSmt() throws XtumlException;
    public ExpressionAsStatementSet R451_is_a_ExpressionAsStatement() throws XtumlException;
    public ForSmtSet R451_is_a_ForSmt() throws XtumlException;
    public GenerateSet R451_is_a_Generate() throws XtumlException;
    public HaltSet R451_is_a_Halt() throws XtumlException;
    public IfSmtSet R451_is_a_IfSmt() throws XtumlException;
    public NullSmtSet R451_is_a_NullSmt() throws XtumlException;
    public RelateSmtSet R451_is_a_RelateSmt() throws XtumlException;
    public ReturnSmtSet R451_is_a_ReturnSmt() throws XtumlException;
    public UnrelateSmtSet R451_is_a_UnrelateSmt() throws XtumlException;
    public WhileSmtSet R451_is_a_WhileSmt() throws XtumlException;
    public VariableSet R457_declares_Variable() throws XtumlException;
    public StatementSet R477_executes_after_Statement() throws XtumlException;
    public StatementSet R477_executes_before_Statement() throws XtumlException;
    public FinalizationSet R485_finalizes_Finalization() throws XtumlException;
    public ExpressionSet R775_may_contain_Expression() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/architecture/statement/StatementSet.java <==
package io.ciera.tool.sql.architecture.statement;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.invocable.CodeBlockSet;
import io.ciera.tool.sql.architecture.statement.BreakSmtSet;
import io.ciera.tool.sql.architecture.statement.ContinueSmtSet;
import io.ciera.tool.sql.architecture.statement.DeleteSmtSet;
import io.ciera.tool.sql.architecture.statement.ExpressionAsStatementSet;
import io.ciera.tool.sql.architecture.statement.FinalizationSet;
import io.ciera.tool.sql.architecture.statement.ForSmtSet;
import io.ciera.tool.sql.architecture.statement.GenerateSet;
import io.ciera.tool.sql.architecture.statement.HaltSet;
import io.ciera.tool.sql.architecture.statement.IfSmtSet;
import io.ciera.tool.sql.architecture.statement.NullSmtSet;
import io.ciera.tool.sql.architecture.statement.RelateSmtSet;
import io.ciera.tool.sql.architecture.statement.ReturnSmtSet;
import io.ciera.tool.sql.architecture.statement.StatementSet;
import io.ciera.tool.sql.architecture.statement.UnrelateSmtSet;
import io.ciera.tool.sql.architecture.statement.VariableSet;
import io.ciera.tool.sql.architecture.statement.WhileSmtSet;


public interface StatementSet extends IInstanceSet<StatementSet,Statement> {

    // attributes
    public void setStatement_number( String m_statement_number ) throws XtumlException;
    public void setNext_statement_number( String ref_next_statement_number ) throws XtumlException;
    public void setParent_name( String ref_parent_name ) throws XtumlException;
    public void setPrefix( String m_prefix ) throws XtumlException;
    public void setBlock_number( String ref_block_number ) throws XtumlException;
    public void setBody_name( String ref_body_name ) throws XtumlException;
    public void setActions( String m_actions ) throws XtumlException;
    public void setParent_package( String ref_parent_package ) throws XtumlException;


    // selections
    public CodeBlockSet R450_is_contained_by_CodeBlock() throws XtumlException;
    public BreakSmtSet R451_is_a_BreakSmt() throws XtumlException;
    public ContinueSmtSet R451_is_a_ContinueSmt() throws XtumlException;
    public DeleteSmtSet R451_is_a_DeleteSmt() throws XtumlException;
    public ExpressionAsStatementSet R451_is_a_ExpressionAsStatement() throws XtumlException;
    public ForSmtSet R451_is_a_ForSmt() throws XtumlException;
    public GenerateSet R451_is_a_Generate() throws XtumlException;
    public HaltSet R451_is_a_Halt() throws XtumlException;
    public IfSmtSet R451_is_a_IfSmt() throws XtumlException;
    public NullSmtSet R451_is_a_NullSmt() throws XtumlException;
    public RelateSmtSet R451_is_a_RelateSmt() throws XtumlException;
    public ReturnSmtSet R451_is_a_ReturnSmt() throws XtumlException;
    public UnrelateSmtSet R451_is_a_UnrelateSmt() throws XtumlException;
    public WhileSmtSet R451_is_a_WhileSmt() throws XtumlException;
    public VariableSet R457_declares_Variable() throws XtumlException;
    public StatementSet R477_executes_after_Statement() throws XtumlException;
    public StatementSet R477_executes_before_Statement() throws XtumlException;
    public FinalizationSet R485_finalizes_Finalization() throws XtumlException;
    public ExpressionSet R775_may_contain_Expression() throws XtumlException;


}
